The MANHATAN data frame has 25 rows and 3 columns.
The observations were obtained in a study carried out by the sociologist Leo Srole and describe the cross-classification of 1660 adults in Manhattan, ages 20-59, obtained from a sample of midtown residents.
data(MANHATAN)This data frame contains the following columns:
A factor with levels:
Well;
Misy;
Mosy;
Imp.
A factor with levels:
A;
B;
C;
D;
E;
F.
The absolute frequencies of which factor.
van der Ark, A. L. 1999. Contributions to Latent Budget Analysis, a tool for the analysis of compositional data. Ph.D. Thesis University of Utrecht.