Learn R Programming

lba (version 1.0)

goodnessfit: Goodness of Fit results for Latent Budget Analysis

Description

The goodness of fit results assesses how well the model fits the data. It consists of measures of the resemblance between the observed and the expected data, and the parsimony of the model.

Usage

goodnessfit(object)

Arguments

object
An object of one of following classes: lba.ls, lba.ls.fe, lba.ls.logit, lba.mle, lba.mle.fe, lba.mle.logit

Value

  • The goodnessfit function to the method lba.mle, lba.mle.fe and lba.mle.logit returns a list with the slots:
  • dfdbDegrees of freedom of the base model
  • dfdDegrees of freedom of the full model
  • G2bLikelihood ratio statistic of the base model
  • G2Likelihood ratio statistic of the full model
  • chi2bChi-square statistic of the base model
  • chi2Chi-square statistic of the full model
  • proG1P-value of likelihood ratio statistic of the base model
  • proGP-value of likelihood ratio statistic of the full model
  • prochi1P-value of chi-square statistic of the base model
  • prochiP-value of chi-square statistic of the full model
  • AICbAIC criteria of the base model
  • AICCAIC criteria of the full model
  • BICbBIC criteria of the base model
  • BICCBIC criteria of the full model
  • CAICbCAIC criteria of the base model
  • CAICCAIC criteria of the full model
  • delta1Normed fit index
  • delta2Normed fit index modified
  • rho1Bollen index
  • rho2Tucker-Lewis index
  • RSS1Residual sum of square of the base model
  • RSSResidual sum of square of the full model
  • impRSSImprovement of RSS
  • impPBImprovement per budget
  • impDFAverage improvement per degree of freedom
  • D1Index of dissimilarity of the base model
  • DIndex of dissimilarity of the full model
  • pccbProportion of correctly classified data of the base model
  • pccProportion of correctly classified data of the full model
  • impDImprovement of proportion of correctly classified data
  • impPCCBImprovement of Proportion of correctly classified data per budget
  • AimpPCCDFAverage improvement of Proportion of correctly classified data per degree of freedom
  • mad1Mean angular deviation of the base model
  • madkMean angular deviation of the full model
  • impMadImprovement mean angular deviation
  • impPBsatImprovement mean angular deviation per budget
  • impDFsatAverage improvement mean angular deviation per degree of freedom
  • The goodnessfit function to the method lba.ls, lba.ls.fe and lba.ls.logit returns a list with the slots:
  • dfdbDegrees of freedom of the base model
  • dfdDegrees of freedom of the full model
  • RSS1Residual sum of square of the base model
  • RSSResidual sum of square of the full model
  • impRSSImprovement of RSS
  • impPBImprovement per budget
  • impDFAverage improvement per degree of freedom
  • wRSS1Weighted residual sum of square of the base model
  • wRSSWeighted residual sum of square of the full model
  • impwRSSImprovement of wRSS
  • D1Index of dissimilarity of the base model
  • DIndex of dissimilarity of the full model
  • pccbProportion of correctly classified data of the base model
  • pccProportion of correctly classified data of the full model
  • impDImprovement of proportion of correctly classified data
  • impPCCBImprovement of Proportion of correctly classified data per budget
  • AimpPCCDFAverage improvement of Proportion of correctly classified data per degree of freedom
  • mad1Mean angular deviation of the base model
  • madkMean angular deviation of the full model
  • impMadImprovement mean angular deviation
  • impPBsatImprovement mean angular deviation per budget
  • impDFsatAverage improvement mean angular deviation per degree of freedom

References

Agresti, Alan. 2002. Categorical Data Analysis, second edition. Hoboken: John Wiley & Sons. van der Ark, A. L. 1999. Contributions to Latent Budget Analysis, a tool for the analysis of compositional data. Ph.D. Thesis University of Utrecht.

See Also

print.goodnessfit, lba

Examples

Run this code
data('votB')

# Using LS method (default) without constraint
# K = 2
ex1 <- lba(city ~ parties,
           votB,
           K = 2)

gx1 <- goodnessfit(ex1)
gx1

# Using MLE method without constraint
# K = 2
exm <- lba(city ~ parties,
           votB,
           K = 2,
           method='mle')

gxm <- goodnessfit(exm)
gxm

Run the code above in your browser using DataLab