Learn R Programming

lba (version 1.0)

MANHATAN: The Midtown Manhattan Study

Description

The MANHATAN data frame has 25 rows and 3 columns. The observations were obtained in a study carried out by the sociologist Leo Srole and describe the cross-classification of 1660 adults in Manhattan, ages 20-59, obtained from a sample of midtown residents.

Usage

MANHATAN

Arguments

source

Goodman, L. A. (1987) New Methods for Analysing the Intrinsic Character of Qualitative Variables Using Cross-Classified Data. American Journal of Sociology 93, 529--583.

References

van der Ark, A. L. 1999. Contributions to Latent Budget Analysis, a tool for the analysis of compositional data. Ph.D. Thesis University of Utrecht.